#!/bin/bash
#rm -rf postgres_tpch_databases/

#abort on first error
#set -e



mkdir -p postgres_tpch_databases

SCALE_FACTORS_TO_LOAD=1

for i in $SCALE_FACTORS_TO_LOAD; do
	echo "Convert TPC-H Benchmark database csv files in Postgres compatible format"
	mkdir -p "$PWD/tpch_cleaned_tables/SF$i"
        for file in customer.tbl  lineitem.tbl  nation.tbl  orders.tbl  partsupp.tbl  part.tbl  region.tbl  supplier.tbl; do
             if [ ! -e "$PWD/tpch_cleaned_tables/SF$i/$file" ]; then
                  ROWS=$(cat "$PWD/tpch_raw_tables/SF$i/$file" | wc -l)
                  echo "Converting tbl file: $file having $ROWS rows"
                  cat "$PWD/tpch_raw_tables/SF$i/$file" | sed 's/|$//' > "$PWD/tpch_cleaned_tables/SF$i/$file"
             fi
        done


	echo "Import TPC-H Benchmark database in Postgres for scale factor $i"
	./build/bin/initdb -D $PWD/postgres_tpch_databases/SF$i
	./build/bin/postgres -D $PWD/postgres_tpch_databases/SF$i &
	#wait for postgres to start up
	sleep 5
	PATH_TO_TPCH_CSV_FILES="$PWD/tpch_cleaned_tables/SF$i"
	echo "init database..."
	./build/bin/createdb $USER
	echo "create schema..."
	./build/bin/psql --file=tpch_2_15.0/dbgen/dss.ddl
	echo "import CSV Files:"
	echo "Customer..."
	./build/bin/psql --command="copy Customer from '$PATH_TO_TPCH_CSV_FILES/customer.tbl' DELIMITER '|' CSV;"
	echo "REGION..."
	./build/bin/psql --command="copy REGION from '$PATH_TO_TPCH_CSV_FILES/region.tbl' DELIMITER '|' CSV;"
	echo "PART..."
	./build/bin/psql --command="copy PART from '$PATH_TO_TPCH_CSV_FILES/part.tbl' DELIMITER '|' CSV;"
	echo "PARTSUPP..."
	./build/bin/psql --command="copy PARTSUPP from '$PATH_TO_TPCH_CSV_FILES/partsupp.tbl' DELIMITER '|' CSV;"
	echo "LINEITEM..."
	./build/bin/psql --command="copy LINEITEM from '$PATH_TO_TPCH_CSV_FILES/lineitem.tbl' DELIMITER '|' CSV;"
	echo "ORDERS..."
	./build/bin/psql --command="copy ORDERS from '$PATH_TO_TPCH_CSV_FILES/orders.tbl' DELIMITER '|' CSV;"
	echo "SUPPLIER..."
	./build/bin/psql --command="copy SUPPLIER from '$PATH_TO_TPCH_CSV_FILES/supplier.tbl' DELIMITER '|' CSV;"
	echo "NATION..."
	./build/bin/psql --command="copy NATION from '$PATH_TO_TPCH_CSV_FILES/nation.tbl' DELIMITER '|' CSV;"
	#create integrity constraints
	psql --file external_source/tpch-alter.sql 
	#terminate postgres
	kill -INT `head -1 "$PWD/postgres_tpch_databases/SF$i/postmaster.pid"`
done

echo "Imported all data sets in posgres postgres_tpch_databases"
exit 0

